@@ -1,5 +1,5 @@
 window.BENCHMARK_DATA = {
-  "lastUpdate": 1627452628152,
+  "lastUpdate": 1634328810850,
   "repoUrl": "https://github.com/Anexen/pyxirr",
   "entries": {
     "Rust Benchmark": [
@@ -1238,6 +1238,552 @@ window.BENCHMARK_DATA = {
             "unit": "ns/iter"
           }
         ]
+      },
+      {
+        "commit": {
+          "author": {
+            "email": "avolk93@gmail.com",
+            "name": "Anexen",
+            "username": "Anexen"
+          },
+          "committer": {
+            "email": "avolk93@gmail.com",
+            "name": "Anexen",
+            "username": "Anexen"
+          },
+          "distinct": true,
+          "id": "7301b86ee9b4670050ed8293f6fadcc458090460",
+          "message": "bump version to 0.6.1",
+          "timestamp": "2021-07-28T14:00:42+03:00",
+          "tree_id": "9c5161a124cef58fa68a2f030c5aa928425a9d88",
+          "url": "https://github.com/Anexen/pyxirr/commit/7301b86ee9b4670050ed8293f6fadcc458090460"
+        },
+        "date": 1627470314881,
+        "tool": "cargo",
+        "benches": [
+          {
+            "name": "bench_python_100",
+            "value": 19419053,
+            "range": "± 2733622",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_python_1000",
+            "value": 50381213,
+            "range": "± 2356630",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_python_500",
+            "value": 64255452,
+            "range": "± 4228234",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_rust_100",
+            "value": 51475,
+            "range": "± 4714",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_rust_1000",
+            "value": 455647,
+            "range": "± 36357",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_rust_500",
+            "value": 280217,
+            "range": "± 23979",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_scipy_100",
+            "value": 1017151,
+            "range": "± 111913",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_scipy_1000",
+            "value": 4626777,
+            "range": "± 627886",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_scipy_500",
+            "value": 3295630,
+            "range": "± 365983",
+            "unit": "ns/iter"
+          }
+        ]
+      },
+      {
+        "commit": {
+          "author": {
+            "email": "avolk93@gmail.com",
+            "name": "Anexen",
+            "username": "Anexen"
+          },
+          "committer": {
+            "email": "avolk93@gmail.com",
+            "name": "Anexen",
+            "username": "Anexen"
+          },
+          "distinct": true,
+          "id": "774b538543bd4a1b8425b3863f57e04daa3457f6",
+          "message": "bump version to 0.6.2",
+          "timestamp": "2021-08-06T08:34:20+03:00",
+          "tree_id": "e83c9b9425dd57ad0b0a635d84e8324efdc4b525",
+          "url": "https://github.com/Anexen/pyxirr/commit/774b538543bd4a1b8425b3863f57e04daa3457f6"
+        },
+        "date": 1628228275604,
+        "tool": "cargo",
+        "benches": [
+          {
+            "name": "bench_python_100",
+            "value": 17517858,
+            "range": "± 2334503",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_python_1000",
+            "value": 45649568,
+            "range": "± 3747439",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_python_500",
+            "value": 58891735,
+            "range": "± 4718766",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_rust_100",
+            "value": 47932,
+            "range": "± 7748",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_rust_1000",
+            "value": 433790,
+            "range": "± 71796",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_rust_500",
+            "value": 265429,
+            "range": "± 45078",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_scipy_100",
+            "value": 1000190,
+            "range": "± 174505",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_scipy_1000",
+            "value": 4652384,
+            "range": "± 1212004",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_scipy_500",
+            "value": 3324031,
+            "range": "± 438182",
+            "unit": "ns/iter"
+          }
+        ]
+      },
+      {
+        "commit": {
+          "author": {
+            "email": "avolk93@gmail.com",
+            "name": "Alexander Volkovsky",
+            "username": "Anexen"
+          },
+          "committer": {
+            "email": "noreply@github.com",
+            "name": "GitHub",
+            "username": "web-flow"
+          },
+          "distinct": true,
+          "id": "4591e58dc44df4d9c28ec26bd0aa96d679eb129a",
+          "message": "XIRR improvements (#15)\n\n* add more xirr tests\r\n\r\n* handle XIRR close to -1\r\n\r\n* fix nfv signature; always return None instead of nan",
+          "timestamp": "2021-08-17T23:34:05+03:00",
+          "tree_id": "6bf1563f0abe4b1a8b2ab68adac2f45bb135d027",
+          "url": "https://github.com/Anexen/pyxirr/commit/4591e58dc44df4d9c28ec26bd0aa96d679eb129a"
+        },
+        "date": 1629232575173,
+        "tool": "cargo",
+        "benches": [
+          {
+            "name": "bench_python_100",
+            "value": 15147450,
+            "range": "± 42629",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_python_1000",
+            "value": 38173503,
+            "range": "± 219022",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_python_500",
+            "value": 49235102,
+            "range": "± 193495",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_rust_100",
+            "value": 41880,
+            "range": "± 555",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_rust_1000",
+            "value": 366457,
+            "range": "± 18005",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_rust_500",
+            "value": 225892,
+            "range": "± 1816",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_scipy_100",
+            "value": 709607,
+            "range": "± 10262",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_scipy_1000",
+            "value": 3531798,
+            "range": "± 14053",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_scipy_500",
+            "value": 2430346,
+            "range": "± 8465",
+            "unit": "ns/iter"
+          }
+        ]
+      },
+      {
+        "commit": {
+          "author": {
+            "email": "avolk93@gmail.com",
+            "name": "Anexen",
+            "username": "Anexen"
+          },
+          "committer": {
+            "email": "avolk93@gmail.com",
+            "name": "Anexen",
+            "username": "Anexen"
+          },
+          "distinct": true,
+          "id": "2dc63451464dc5018909f6a44a1e86e6d014fac4",
+          "message": "bump version to 0.6.3",
+          "timestamp": "2021-08-17T23:42:23+03:00",
+          "tree_id": "42c79e67cc7ec1b1d221a5a5390bc8870c63ec13",
+          "url": "https://github.com/Anexen/pyxirr/commit/2dc63451464dc5018909f6a44a1e86e6d014fac4"
+        },
+        "date": 1629233110951,
+        "tool": "cargo",
+        "benches": [
+          {
+            "name": "bench_python_100",
+            "value": 14442456,
+            "range": "± 41623",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_python_1000",
+            "value": 36442674,
+            "range": "± 278558",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_python_500",
+            "value": 46985716,
+            "range": "± 229327",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_rust_100",
+            "value": 41602,
+            "range": "± 444",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_rust_1000",
+            "value": 365089,
+            "range": "± 16395",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_rust_500",
+            "value": 224746,
+            "range": "± 657",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_scipy_100",
+            "value": 705909,
+            "range": "± 6649",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_scipy_1000",
+            "value": 3463710,
+            "range": "± 12923",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_scipy_500",
+            "value": 2439829,
+            "range": "± 118097",
+            "unit": "ns/iter"
+          }
+        ]
+      },
+      {
+        "commit": {
+          "author": {
+            "email": "avolk93@gmail.com",
+            "name": "Anexen",
+            "username": "Anexen"
+          },
+          "committer": {
+            "email": "avolk93@gmail.com",
+            "name": "Anexen",
+            "username": "Anexen"
+          },
+          "distinct": true,
+          "id": "dd232e633db3726217d969c1a5ca25c2b63a33a8",
+          "message": "wheels for python 3.10",
+          "timestamp": "2021-10-05T21:16:34+03:00",
+          "tree_id": "d48ca856868b76ff56401259c7d71c3e5f33e53b",
+          "url": "https://github.com/Anexen/pyxirr/commit/dd232e633db3726217d969c1a5ca25c2b63a33a8"
+        },
+        "date": 1633457937940,
+        "tool": "cargo",
+        "benches": [
+          {
+            "name": "bench_python_100",
+            "value": 14698377,
+            "range": "± 26294",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_python_1000",
+            "value": 36985943,
+            "range": "± 180722",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_python_500",
+            "value": 47843738,
+            "range": "± 217804",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_rust_100",
+            "value": 41530,
+            "range": "± 442",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_rust_1000",
+            "value": 368686,
+            "range": "± 7541",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_rust_500",
+            "value": 224797,
+            "range": "± 11199",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_scipy_100",
+            "value": 705477,
+            "range": "± 4920",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_scipy_1000",
+            "value": 3483412,
+            "range": "± 7999",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_scipy_500",
+            "value": 2438863,
+            "range": "± 9318",
+            "unit": "ns/iter"
+          }
+        ]
+      },
+      {
+        "commit": {
+          "author": {
+            "email": "avolk93@gmail.com",
+            "name": "Anexen",
+            "username": "Anexen"
+          },
+          "committer": {
+            "email": "avolk93@gmail.com",
+            "name": "Anexen",
+            "username": "Anexen"
+          },
+          "distinct": true,
+          "id": "2ee135629129c94115b47503fa0bf55869ab7759",
+          "message": "Merge branch 'main' of github.com:Anexen/pyxirr",
+          "timestamp": "2021-10-05T21:20:43+03:00",
+          "tree_id": "3fab163a6e5a51798dcb3aa7bee97090be65645b",
+          "url": "https://github.com/Anexen/pyxirr/commit/2ee135629129c94115b47503fa0bf55869ab7759"
+        },
+        "date": 1633458135956,
+        "tool": "cargo",
+        "benches": [
+          {
+            "name": "bench_python_100",
+            "value": 12969342,
+            "range": "± 1957409",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_python_1000",
+            "value": 32659186,
+            "range": "± 182814",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_python_500",
+            "value": 42328093,
+            "range": "± 151240",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_rust_100",
+            "value": 36695,
+            "range": "± 484",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_rust_1000",
+            "value": 324887,
+            "range": "± 16877",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_rust_500",
+            "value": 198149,
+            "range": "± 12989",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_scipy_100",
+            "value": 698899,
+            "range": "± 4528",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_scipy_1000",
+            "value": 3455859,
+            "range": "± 11689",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_scipy_500",
+            "value": 2412930,
+            "range": "± 9990",
+            "unit": "ns/iter"
+          }
+        ]
+      },
+      {
+        "commit": {
+          "author": {
+            "email": "avolk93@gmail.com",
+            "name": "Anexen",
+            "username": "Anexen"
+          },
+          "committer": {
+            "email": "avolk93@gmail.com",
+            "name": "Anexen",
+            "username": "Anexen"
+          },
+          "distinct": true,
+          "id": "17434f8687b8eefeb412df0edf5e6df9a0d70c65",
+          "message": "bump version to 0.6.4",
+          "timestamp": "2021-10-15T23:11:09+03:00",
+          "tree_id": "7803b390c122c1707dc401fa969c738978608cf1",
+          "url": "https://github.com/Anexen/pyxirr/commit/17434f8687b8eefeb412df0edf5e6df9a0d70c65"
+        },
+        "date": 1634328810833,
+        "tool": "cargo",
+        "benches": [
+          {
+            "name": "bench_python_100",
+            "value": 14878175,
+            "range": "± 837130",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_python_1000",
+            "value": 37913833,
+            "range": "± 2681919",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_python_500",
+            "value": 47918752,
+            "range": "± 746711",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_rust_100",
+            "value": 41643,
+            "range": "± 457",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_rust_1000",
+            "value": 362898,
+            "range": "± 17787",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_rust_500",
+            "value": 224098,
+            "range": "± 9653",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_scipy_100",
+            "value": 715927,
+            "range": "± 6419",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_scipy_1000",
+            "value": 3581566,
+            "range": "± 13584",
+            "unit": "ns/iter"
+          },
+          {
+            "name": "bench_scipy_500",
+            "value": 2478015,
+            "range": "± 18263",
+            "unit": "ns/iter"
+          }
+        ]
       }
     ]
   }
