@@ -6,5 +6,5 @@ mod periodic;
 mod scheduled;
 
 pub use models::{DateLike, InvalidPaymentsError};
-pub use periodic::{fv, irr, mirr, nfv, nper, npv, pmt, pv};
+pub use periodic::{fv, ipmt, irr, mirr, nfv, nper, npv, pmt, ppmt, pv, rate};
 pub use scheduled::{xfv, xirr, xnfv, xnpv};
